---
title: <span class="badge object-type-scalar"></span> KiloHashesPerSecond
---
# <span class="badge object-type-scalar"></span> KiloHashesPerSecond

Hash rate: kilohashes/sec

## Definition

```python
# Hash rate: kilohashes/sec
KiloHashesPerSecond: typing.Literal["KHs"] = "KHs"
```
